var NAVTREEINDEX19 =
{
"opencl_2matrix__operations_8hpp.html#a9af548eaf628c556dcd90938a2e11528":[7,0,3,4,3,6,3],
"opencl_2matrix__operations_8hpp.html#a9b46aa01fc67f7d7fbc95056a1f050c6":[7,0,3,4,3,6,1],
"opencl_2matrix__operations_8hpp.html#aa1db022508f1ca9f0a42269205ac2565":[7,0,3,4,3,6,23],
"opencl_2matrix__operations_8hpp.html#aa37f02ed2a2f38dfea3abbfdeb5aab95":[7,0,3,4,3,6,12],
"opencl_2matrix__operations_8hpp.html#ab334de39e0a14eec29eef532cf625be9":[7,0,3,4,3,6,19],
"opencl_2matrix__operations_8hpp.html#ab4be1fe81c4ca79108c4db2d7b23ec2c":[7,0,3,4,3,6,7],
"opencl_2matrix__operations_8hpp.html#ac04e7aa6506170485722039430d329ab":[7,0,3,4,3,6,14],
"opencl_2matrix__operations_8hpp.html#ac35599cd7a904c6187e3d1e4c5b2d38b":[7,0,3,4,3,6,35],
"opencl_2matrix__operations_8hpp.html#ac368f3b6c47973062b06a7b765ca4521":[7,0,3,4,3,6,21],
"opencl_2matrix__operations_8hpp.html#aceca2a25a53f4b5c0dd836c8d024b170":[7,0,3,4,3,6,10],
"opencl_2matrix__operations_8hpp.html#adf9d9e0232c7731006e942e6f1eb787c":[7,0,3,4,3,6,27],
"opencl_2matrix__operations_8hpp.html#ae14982b121ba058e0cc0569b93f80646":[7,0,3,4,3,6,29],
"opencl_2matrix__operations_8hpp.html#ae3f1e3bfcb56428f4e73e030ebae7066":[7,0,3,4,3,6,20],
"opencl_2matrix__operations_8hpp.html#ae9e45a4202d75a28076b78d133ba9379":[7,0,3,4,3,6,5],
"opencl_2matrix__operations_8hpp.html#af22fcf715396698796b26f45bece179e":[7,0,3,4,3,6,17],
"opencl_2matrix__operations_8hpp.html#af9c69aabdf179456bdf212e4b34e8b9a":[7,0,3,4,3,6,8],
"opencl_2matrix__operations_8hpp.html#affe958b9b7dc9ad1986e2b2b2cdb757a":[7,0,3,4,3,6,18],
"opencl_2matrix__operations_8hpp_source.html":[7,0,3,4,3,6],
"opencl_2misc__operations_8hpp.html":[7,0,3,4,3,7],
"opencl_2misc__operations_8hpp.html#ad939e77692cf9b3c5746b11ba9ff024c":[7,0,3,4,3,7,0],
"opencl_2misc__operations_8hpp_source.html":[7,0,3,4,3,7],
"opencl_2nmf__operations_8hpp.html":[7,0,3,4,3,8],
"opencl_2nmf__operations_8hpp.html#a9f0c073c618b76460027457d7331ba33":[7,0,3,4,3,8,0],
"opencl_2nmf__operations_8hpp_source.html":[7,0,3,4,3,8],
"opencl_2scalar__operations_8hpp.html":[7,0,3,4,3,9],
"opencl_2scalar__operations_8hpp.html#a11ed680640c9598490f6a98c16828d77":[7,0,3,4,3,9,0],
"opencl_2scalar__operations_8hpp.html#a54a07e7d66ac02c7879af93ce5eb2336":[7,0,3,4,3,9,2],
"opencl_2scalar__operations_8hpp.html#ac02d4b9c2ac529bcd8a76c081c9702eb":[7,0,3,4,3,9,1],
"opencl_2scalar__operations_8hpp.html#af17184fcbab9dbaa872694436946a174":[7,0,3,4,3,9,3],
"opencl_2scalar__operations_8hpp_source.html":[7,0,3,4,3,9],
"opencl_2sparse__matrix__operations_8hpp.html":[7,0,3,4,3,10],
"opencl_2sparse__matrix__operations_8hpp.html#a0a16aa6006192d8f3f127b48bfcf9ca5":[7,0,3,4,3,10,18],
"opencl_2sparse__matrix__operations_8hpp.html#a144fd7dc25be2029356c24f07f281edc":[7,0,3,4,3,10,0],
"opencl_2sparse__matrix__operations_8hpp.html#a1b40072f44f7e9bd156d9560ca7ee30e":[7,0,3,4,3,10,11],
"opencl_2sparse__matrix__operations_8hpp.html#a1fcccd84db8c1659e268e6d7719df94e":[7,0,3,4,3,10,25],
"opencl_2sparse__matrix__operations_8hpp.html#a20c8cd535c54bba79b1912abce227d04":[7,0,3,4,3,10,22],
"opencl_2sparse__matrix__operations_8hpp.html#a246453c807f9114ad40e6ae5c22dabc2":[7,0,3,4,3,10,10],
"opencl_2sparse__matrix__operations_8hpp.html#a256a599dedd093618c9936e85a75b3d4":[7,0,3,4,3,10,24],
"opencl_2sparse__matrix__operations_8hpp.html#a3a97d7d39ed0063efc0e2a7184c63711":[7,0,3,4,3,10,5],
"opencl_2sparse__matrix__operations_8hpp.html#a435057e12f3596a3bf78e4267b7f7c00":[7,0,3,4,3,10,21],
"opencl_2sparse__matrix__operations_8hpp.html#a58540b3dfdf2451f59a8d69b0d503977":[7,0,3,4,3,10,8],
"opencl_2sparse__matrix__operations_8hpp.html#a66050024d4fd7fe421fdec79b082268e":[7,0,3,4,3,10,3],
"opencl_2sparse__matrix__operations_8hpp.html#a720d4cb00c0c08602f62608ecaa9a835":[7,0,3,4,3,10,1],
"opencl_2sparse__matrix__operations_8hpp.html#a72fb925402b34c304e02fb4feafb8bc9":[7,0,3,4,3,10,16],
"opencl_2sparse__matrix__operations_8hpp.html#a7ecec23db21c19f887742bdecb69b2d3":[7,0,3,4,3,10,13],
"opencl_2sparse__matrix__operations_8hpp.html#a7f4c33a310f17f3379aac2f88348f85b":[7,0,3,4,3,10,7],
"opencl_2sparse__matrix__operations_8hpp.html#a82d0e161d210b339dbda37d6ebc6318f":[7,0,3,4,3,10,2],
"opencl_2sparse__matrix__operations_8hpp.html#a83199d78f9adbf3b16034fc8a093ed38":[7,0,3,4,3,10,15],
"opencl_2sparse__matrix__operations_8hpp.html#ab533b18fa44834dcb24da21403e151a9":[7,0,3,4,3,10,17],
"opencl_2sparse__matrix__operations_8hpp.html#ac0ec44510ac05abee01a6b869be68d0c":[7,0,3,4,3,10,20],
"opencl_2sparse__matrix__operations_8hpp.html#adc9e31f7f23c948acc29e15970acd07f":[7,0,3,4,3,10,9],
"opencl_2sparse__matrix__operations_8hpp.html#adda9f05f3e9ac885e8603f5eed57db1b":[7,0,3,4,3,10,23],
"opencl_2sparse__matrix__operations_8hpp.html#ae0b9b74ba21c79a3d9421bc68c74712b":[7,0,3,4,3,10,6],
"opencl_2sparse__matrix__operations_8hpp.html#ae166d736e11c7a6d102115fcb0dddf03":[7,0,3,4,3,10,19],
"opencl_2sparse__matrix__operations_8hpp.html#ae83a113e8217c08655530df7d0b846b1":[7,0,3,4,3,10,4],
"opencl_2sparse__matrix__operations_8hpp.html#af50b89f6d9d21d281be8613a54f7d96e":[7,0,3,4,3,10,12],
"opencl_2sparse__matrix__operations_8hpp.html#af7d2c1881e671ae1dd573bb49b900c5b":[7,0,3,4,3,10,14],
"opencl_2sparse__matrix__operations_8hpp_source.html":[7,0,3,4,3,10],
"opencl_2vandermonde__matrix__operations_8hpp.html":[7,0,3,4,3,11],
"opencl_2vandermonde__matrix__operations_8hpp.html#a4fcce6e27674c9c10dc323440cfbfbb6":[7,0,3,4,3,11,0],
"opencl_2vandermonde__matrix__operations_8hpp_source.html":[7,0,3,4,3,11],
"opencl_2vector__operations_8hpp.html":[7,0,3,4,3,12],
"opencl_2vector__operations_8hpp.html#a03243122a1a2c45b41fb02d04ce2f21b":[7,0,3,4,3,12,0],
"opencl_2vector__operations_8hpp.html#a23aad63531d04768c6d28c3f25ce64f4":[7,0,3,4,3,12,4],
"opencl_2vector__operations_8hpp.html#a2aab820de0a4fb811bc09ca84b3c4e42":[7,0,3,4,3,12,7],
"opencl_2vector__operations_8hpp.html#a346e36e15039793998dd606f6e6c2543":[7,0,3,4,3,12,14],
"opencl_2vector__operations_8hpp.html#a5b18ba2b0fe0d7f393d99d6c0d0cc3f0":[7,0,3,4,3,12,8],
"opencl_2vector__operations_8hpp.html#a5c62e6fe8e1151f73f2764337bb17b8f":[7,0,3,4,3,12,6],
"opencl_2vector__operations_8hpp.html#a64046186f30c897d35ea7facef3b4c4e":[7,0,3,4,3,12,20],
"opencl_2vector__operations_8hpp.html#a66ecf8efa0b41147e85710db81cc9e37":[7,0,3,4,3,12,9],
"opencl_2vector__operations_8hpp.html#a71a1b9f38905691db366f206dfea4bd5":[7,0,3,4,3,12,13],
"opencl_2vector__operations_8hpp.html#a87adbaa14d91e0c3b0cb67b9c85f7e74":[7,0,3,4,3,12,18],
"opencl_2vector__operations_8hpp.html#a886967c879e0ff911598d80ea2f8b1b0":[7,0,3,4,3,12,19],
"opencl_2vector__operations_8hpp.html#a96c7c34e9ab708abe647c5d1eb7f6b07":[7,0,3,4,3,12,12],
"opencl_2vector__operations_8hpp.html#a99e0dc95b92ed1fa56c13ec48caf9aab":[7,0,3,4,3,12,1],
"opencl_2vector__operations_8hpp.html#ab8cd375f30d0899d7739883bcfc37597":[7,0,3,4,3,12,21],
"opencl_2vector__operations_8hpp.html#abc7becb6439b83a538e28e64f005ed3b":[7,0,3,4,3,12,3],
"opencl_2vector__operations_8hpp.html#ac01c4f0830ba78e361d84e120bbe588b":[7,0,3,4,3,12,17],
"opencl_2vector__operations_8hpp.html#ac170765011d5fabf045d6adae0916f95":[7,0,3,4,3,12,11],
"opencl_2vector__operations_8hpp.html#ac79bc14c508a0830434970c2cee89641":[7,0,3,4,3,12,10],
"opencl_2vector__operations_8hpp.html#ae6af79b78b4fb3986863b3d617c0362f":[7,0,3,4,3,12,16],
"opencl_2vector__operations_8hpp.html#ae8fdcd903786ddaaf80f31ab99f6f296":[7,0,3,4,3,12,5],
"opencl_2vector__operations_8hpp.html#af2e502723670d95745339eedc5a4ed98":[7,0,3,4,3,12,2],
"opencl_2vector__operations_8hpp.html#af95960bfd18fd4a21c7b003c6cbaa329":[7,0,3,4,3,12,22],
"opencl_2vector__operations_8hpp.html#afd5fb48f2e4cbe4ecd561d8b4af424a7":[7,0,3,4,3,12,15],
"opencl_2vector__operations_8hpp_source.html":[7,0,3,4,3,12],
"opencl_8cpp.html":[7,0,0,0,3],
"opencl_8cpp.html#a017c0eee41b5f529d1e9a9492c171fe2":[7,0,0,0,3,2],
"opencl_8cpp.html#a3c8d8d5c04fe6deddae061ef4d5945d5":[7,0,0,0,3,4],
"opencl_8cpp.html#a5200eec7d1a17198a5f76785a1f53417":[7,0,0,0,3,0],
"opencl_8cpp.html#a8de3ed741dadc9c979a4ff17c0a9116e":[7,0,0,0,3,1],
"opencl_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,0,0,3,3],
"opencl_8cpp_source.html":[7,0,0,0,3],
"opencl_8hpp.html":[7,0,3,0,4],
"opencl_8hpp.html#a347eef11410dffb4b31b28657538290e":[7,0,3,0,4,0],
"opencl_8hpp.html#a54957655bb85f822921cc7cf6bd9f222":[7,0,3,0,4,3],
"opencl_8hpp.html#a726ec869b2a56a08da262111f3b70b41":[7,0,3,0,4,1],
"opencl_8hpp.html#af5b9966832bc253b34c2cfa3f8b97bc8":[7,0,3,0,4,2],
"opencl_8hpp_source.html":[7,0,3,0,4],
"pages.html":[],
"platform_8hpp.html":[7,0,3,7,11],
"platform_8hpp.html#ae1e931f6efd155240b33ca440dfcfef5":[7,0,3,7,11,1],
"platform_8hpp_source.html":[7,0,3,7,11],
"power-iter_8cpp-example.html":[8,22],
"power-iter_8cpp.html":[7,0,0,1,23],
"power-iter_8cpp_source.html":[7,0,0,1,23],
"power__iter_8hpp.html":[7,0,3,4,31],
"power__iter_8hpp.html#ad8878598e5b2eac306142bab233d3530":[7,0,3,4,31,1],
"power__iter_8hpp_source.html":[7,0,3,4,31],
"predicate_8hpp.html":[7,0,3,5,1],
"predicate_8hpp_source.html":[7,0,3,5,1],
"preset_8hpp.html":[7,0,3,8,12],
"preset_8hpp.html#a0cd1d7c709968115df9dba5f5dc90182":[7,0,3,8,12,5],
"preset_8hpp.html#a118a9aa5a0542f9e8142d1ebca520542":[7,0,3,8,12,3],
"preset_8hpp.html#a15c1f6f63c1ea75a92d667924784db93":[7,0,3,8,12,4],
"preset_8hpp.html#a195b2b9229453b5382fdc3f7ccc6fe0d":[7,0,3,8,12,8],
"preset_8hpp.html#a1a0c7a8cc3f3d6c3f83eb3318534b371":[7,0,3,8,12,21],
"preset_8hpp.html#a1bc706cd21c33ab763e17493ad630590":[7,0,3,8,12,14],
"preset_8hpp.html#a272dba33c525f60e7219bf3738f34b9a":[7,0,3,8,12,20],
"preset_8hpp.html#a2c3a89fb850137f283a4c6972a052293":[7,0,3,8,12,1],
"preset_8hpp.html#a2ea7d83854ba36ff5028f870bb1f3a16":[7,0,3,8,12,18],
"preset_8hpp.html#a3154ab9d455e68c8fd9c6ed44ee71472":[7,0,3,8,12,22],
"preset_8hpp.html#a368f7a9702d88d6e9e11c12e06be3c5f":[7,0,3,8,12,10],
"preset_8hpp.html#a38468d9f1f28d65bdcb612e85163c629":[7,0,3,8,12,12],
"preset_8hpp.html#a47bb115b4b2bc962b5822bedc31e8bbf":[7,0,3,8,12,0],
"preset_8hpp.html#a50969f1c8d216a3e73ae2b5c1359f16f":[7,0,3,8,12,2],
"preset_8hpp.html#a5c58a5b091c79efb1a03fb106fa502a5":[7,0,3,8,12,9],
"preset_8hpp.html#a6848fc8a87f3222e4ec3eb8b672d6aa9":[7,0,3,8,12,19],
"preset_8hpp.html#a75acbbcb8d2dfa2d03d709e2b4428bd3":[7,0,3,8,12,16],
"preset_8hpp.html#a8b0c43d81c15ba65eb31a3aefc5e9353":[7,0,3,8,12,15],
"preset_8hpp.html#a9f8a66625ea862c1b7ab7801fa121ce6":[7,0,3,8,12,6],
"preset_8hpp.html#aa11466374772f68e24f7ec8053dc859f":[7,0,3,8,12,25],
"preset_8hpp.html#aacb00813e109c592fa7683ae2ddadd03":[7,0,3,8,12,11],
"preset_8hpp.html#ab4ef7c337442f4adc745ccb98f3ae820":[7,0,3,8,12,24],
"preset_8hpp.html#abd5430801ef34018b7278bf0aa45604a":[7,0,3,8,12,13],
"preset_8hpp.html#ac3dd793dbe84c335303148e46d8ce97e":[7,0,3,8,12,23],
"preset_8hpp.html#aeef71ec5fc6b936d0d8c00d6f4107a1d":[7,0,3,8,12,17],
"preset_8hpp.html#afbf748dac3c8771c2ba0433b9159e1e2":[7,0,3,8,12,7],
"preset_8hpp_source.html":[7,0,3,8,12],
"prod_8hpp.html":[7,0,3,4,32],
"prod_8hpp.html#a06e80e05ee4b0f5d10d0f2ae40c43e03":[7,0,3,4,32,6],
"prod_8hpp.html#a1ad201229a1e0543e0c643b7bf930103":[7,0,3,4,32,4],
"prod_8hpp.html#a3bba0146e669e012bb7c7380ce780a25":[7,0,3,4,32,9],
"prod_8hpp.html#a4a8191b8e2833645bf9a50cf0385bf84":[7,0,3,4,32,1],
"prod_8hpp.html#a68fb776340b6102fdd9c166bd160191f":[7,0,3,4,32,8],
"prod_8hpp.html#a7c47e75ff33a456724b971893af416ea":[7,0,3,4,32,5],
"prod_8hpp.html#a895bfcd9f3517d830a9d1434d26ba151":[7,0,3,4,32,11],
"prod_8hpp.html#a9854ff8a626083812c3c34bf077210ff":[7,0,3,4,32,3],
"prod_8hpp.html#a9dbf28b182155a8036335d473bf5fa67":[7,0,3,4,32,2],
"prod_8hpp.html#aa18d10f8a90e38bd9ff43c650fc670ef":[7,0,3,4,32,0],
"prod_8hpp.html#ab74c95343f0771f836513281894217cc":[7,0,3,4,32,7],
"prod_8hpp.html#ae2f953a28fd0726963616efc7c6502be":[7,0,3,4,32,10],
"prod_8hpp_source.html":[7,0,3,4,32],
"program_8hpp.html":[7,0,3,7,12],
"program_8hpp_source.html":[7,0,3,7,12],
"qr-method-common_8hpp.html":[7,0,3,4,33],
"qr-method-common_8hpp.html#a04a5ce1f7230502c9d1ee87dcc24c8b4":[7,0,3,4,33,12],
"qr-method-common_8hpp.html#a05717ddd22894376e780b075d59616ed":[7,0,3,4,33,14],
"qr-method-common_8hpp.html#a0737c94fac817b0d0c8444463be7ceb7":[7,0,3,4,33,5],
"qr-method-common_8hpp.html#a15bedacb51ec9b425baf52ee7f68bdba":[7,0,3,4,33,9],
"qr-method-common_8hpp.html#a349e6e78f95ef631a5f2736158766739":[7,0,3,4,33,15],
"qr-method-common_8hpp.html#a366df7768bf52e820fee364334133db1":[7,0,3,4,33,1],
"qr-method-common_8hpp.html#a3a439370108ddfa59c2fcb4136b13c8d":[7,0,3,4,33,16],
"qr-method-common_8hpp.html#a5852aa7527c0599681f1b0fbc753d357":[7,0,3,4,33,4],
"qr-method-common_8hpp.html#a5b5cb81b46208cae772a5e0813f02517":[7,0,3,4,33,13],
"qr-method-common_8hpp.html#a7bfa1c9cb0afb4ca0f975e690f4a8f07":[7,0,3,4,33,6],
"qr-method-common_8hpp.html#a807e733d7bf94d491377fff3905e25d2":[7,0,3,4,33,0],
"qr-method-common_8hpp.html#a8477d884683dafc7e6ca04f2e02a1d1f":[7,0,3,4,33,8],
"qr-method-common_8hpp.html#a8e62fa452895c889f7bad9700300994d":[7,0,3,4,33,10],
"qr-method-common_8hpp.html#aad4cd2951549618c93f74ff26444675f":[7,0,3,4,33,7],
"qr-method-common_8hpp.html#ace85ea4095e9e7404b6f77b767ac000f":[7,0,3,4,33,11],
"qr-method-common_8hpp.html#ae059c4a3216ff6bdc44110377ce34e88":[7,0,3,4,33,2],
"qr-method-common_8hpp.html#ae152dd8fd5f272525bac1b843375d329":[7,0,3,4,33,3],
"qr-method-common_8hpp_source.html":[7,0,3,4,33],
"qr-method_8hpp.html":[7,0,3,4,34],
"qr-method_8hpp.html#a0ce6438b322e096df65112ac6536b0b1":[7,0,3,4,34,10],
"qr-method_8hpp.html#a4983f4960a80f96d1dc3ff5ff23a0ffa":[7,0,3,4,34,5],
"qr-method_8hpp.html#a4d6d704d39ec27eb15a604580eb1df5b":[7,0,3,4,34,9],
"qr-method_8hpp.html#a51cbe06645207f9b3054e8725269cc71":[7,0,3,4,34,7],
"qr-method_8hpp.html#a6308577bb366f4b0698dc43ff75ad4a5":[7,0,3,4,34,2],
"qr-method_8hpp.html#abe64190e92ee58ad753947142204d0f9":[7,0,3,4,34,6],
"qr-method_8hpp.html#abe90cd38a99c15edfb19d57c524dd2d5":[7,0,3,4,34,1],
"qr-method_8hpp.html#ac4a1dce18e411cc95eb72efd802f50d8":[7,0,3,4,34,3],
"qr-method_8hpp.html#acba51b008828151aabb684d1bb9b350f":[7,0,3,4,34,8],
"qr-method_8hpp.html#afb7f93e8826f0e5c8f0c83a825a28cc8":[7,0,3,4,34,4],
"qr-method_8hpp_source.html":[7,0,3,4,34],
"qr_8cpp-example.html":[8,23],
"qr_8hpp.html":[7,0,3,4,35],
"qr_8hpp.html#a0481a094460753dd7fb519c9dda3bdc1":[7,0,3,4,35,15],
"qr_8hpp.html#a08f92f37e68518e1e18dd6ef20b02947":[7,0,3,4,35,0],
"qr_8hpp.html#a0f34407a1e24c1dee933cb03f978d139":[7,0,3,4,35,12],
"qr_8hpp.html#a0ff42f36e98db6c181b16c78f76f0fdb":[7,0,3,4,35,14],
"qr_8hpp.html#a26c2ded0fa31d617f56bad1c90b42374":[7,0,3,4,35,1],
"qr_8hpp.html#a48b9804b36f469aff716174b0dc0b573":[7,0,3,4,35,2],
"qr_8hpp.html#a600f0692e7550cee41cc6382337cd8c5":[7,0,3,4,35,9],
"qr_8hpp.html#a76fc8bf8f5a20c576b7ddbad32d3e56d":[7,0,3,4,35,11],
"qr_8hpp.html#a83f573386903bae3a5379ab4cbfc5e2d":[7,0,3,4,35,4],
"qr_8hpp.html#a9728d85f4f7307ed9096524de8c77cdc":[7,0,3,4,35,5],
"qr_8hpp.html#aa3b53a769e6ce29affb7401b9118fde3":[7,0,3,4,35,8],
"qr_8hpp.html#aa926ae9008c3343c337f2aa5a90e8734":[7,0,3,4,35,7],
"qr_8hpp.html#acfdf9d2d13f373340bf68cffd9586775":[7,0,3,4,35,13],
"qr_8hpp.html#ad5d436e9fd57a66afe69f56d78d22eeb":[7,0,3,4,35,10],
"qr_8hpp.html#adf77bb0fe92ef09522d0458ee9df03db":[7,0,3,4,35,6],
"qr_8hpp.html#ae04154f304cceaa81ae1fc24882fd7ba":[7,0,3,4,35,16],
"qr_8hpp.html#af17ac3429b78effc2d0c0238a9fcf7b1":[7,0,3,4,35,3],
"qr_8hpp_source.html":[7,0,3,4,35],
"qr__method__func_8cpp.html":[7,0,2,0,26],
"qr__method__func_8cpp.html#a0d32ffba1dbd6aa9792b9907998e9656":[7,0,2,0,26,6],
"qr__method__func_8cpp.html#a18f8a7517201b7dbbf9970f170df6b32":[7,0,2,0,26,17],
"qr__method__func_8cpp.html#a27b869a54a6db4b7bb5050fcbf6c85f7":[7,0,2,0,26,11],
"qr__method__func_8cpp.html#a46f47e0b622209a8c6066f06c29af466":[7,0,2,0,26,10],
"qr__method__func_8cpp.html#a6ebf6899d6c1c8b7b9d09be872c05aae":[7,0,2,0,26,0],
"qr__method__func_8cpp.html#a80b7ea4086ab38d04bae426d3c534386":[7,0,2,0,26,15],
"qr__method__func_8cpp.html#a89745f1f6471edc27c9a57e60d94114b":[7,0,2,0,26,18],
"qr__method__func_8cpp.html#a8de3ed741dadc9c979a4ff17c0a9116e":[7,0,2,0,26,1],
"qr__method__func_8cpp.html#a968e8a3776d54730884b6faf1ba422be":[7,0,2,0,26,8],
"qr__method__func_8cpp.html#a99cd2b0abfb1450f4942aacd0d41ba7c":[7,0,2,0,26,12],
"qr__method__func_8cpp.html#a9d5f615c7a1d656c8c7ecbaa7e81c6ab":[7,0,2,0,26,14],
"qr__method__func_8cpp.html#aa3bec89816a022bcb392445adacec81d":[7,0,2,0,26,9],
"qr__method__func_8cpp.html#accb6d386a66b1ad26b6fa5c3f8cf9988":[7,0,2,0,26,5],
"qr__method__func_8cpp.html#ad0d2305bfc2baef8e498c9628e99a936":[7,0,2,0,26,16],
"qr__method__func_8cpp.html#ad5c19ca4f47d3f8ec21232a5af2624e5":[7,0,2,0,26,3],
"qr__method__func_8cpp.html#adea4c31c93158ab7c09c07510b085f1b":[7,0,2,0,26,7],
"qr__method__func_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,26,13],
"qr__method__func_8cpp.html#af1ef6893285540d49fc3ed9ba8aa2c7a":[7,0,2,0,26,4],
"qr__method__func_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,26,2],
"qr__method__func_8cpp.html#afe063343d3b1e9d9665d8cb04dd59c6d":[7,0,2,0,26,19],
"qr__method__func_8cpp_source.html":[7,0,2,0,26],
"qr_method_8cpp-example.html":[8,24],
"range_8hpp.html":[7,0,3,23],
"range_8hpp_source.html":[7,0,3,23],
"reduce_8hpp.html":[7,0,3,4,36],
"reduce_8hpp.html#a2d8b1052933ed0aaa92c4b5b6023d982":[7,0,3,4,36,3],
"reduce_8hpp.html#aea9457e14e3e34ba66a998f319d0718c":[7,0,3,4,36,2],
"reduce_8hpp.html#af13a49603d3e24a5d22a96f74358fb7b":[7,0,3,4,36,0],
"reduce_8hpp.html#afedb3b265da6ca25fd29c235ae8ef639":[7,0,3,4,36,1],
"reduce_8hpp_source.html":[7,0,3,4,36],
"reduction_8hpp.html":[7,0,3,2,0,4],
"reduction_8hpp.html#a9cd5f34a38ce33bd6ae7c7768bde751a":[7,0,3,2,0,4,1],
"reduction_8hpp.html#ac6ef8dd31565adf17006d8373d9ef054":[7,0,3,2,0,4,0],
"reduction_8hpp_source.html":[7,0,3,2,0,4],
"reduction__template_8hpp.html":[7,0,3,2,1,2],
"reduction__template_8hpp_source.html":[7,0,3,2,1,2],
"result__of_8hpp.html":[7,0,3,5,2],
"result__of_8hpp_source.html":[7,0,3,5,2],
"row__major_8hpp.html":[7,0,3,10,4],
"row__major_8hpp.html#a168a8edd0b615b77f2f1da2da28f8ffb":[7,0,3,10,4,0],
"row__major_8hpp.html#a2453eef1148e0ebf3c049dd8060c71d6":[7,0,3,10,4,2],
"row__major_8hpp.html#ac61b7efb6bd14f87ad19a7b7a9f824ad":[7,0,3,10,4,1],
"row__major_8hpp_source.html":[7,0,3,10,4]
};
